Stan Math Library: stan/math/prim/mat/err Directory Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

err Directory Reference

## Files
file | check_cholesky_factor.hpp [code]
file | check_cholesky_factor_corr.hpp [code]
file | check_column_index.hpp [code]
file | check_corr_matrix.hpp [code]
file | check_cov_matrix.hpp [code]
file | check_ldlt_factor.hpp [code]
file | check_lower_triangular.hpp [code]
file | check_matching_dims.hpp [code]
file | check_matching_sizes.hpp [code]
file | check_multiplicable.hpp [code]
file | check_ordered.hpp [code]
file | check_pos_definite.hpp [code]
file | check_pos_semidefinite.hpp [code]
file | check_positive_ordered.hpp [code]
file | check_range.hpp [code]
file | check_row_index.hpp [code]
file | check_simplex.hpp [code]
file | check_spsd_matrix.hpp [code]
file | check_square.hpp [code]
file | check_std_vector_index.hpp [code]
file | check_symmetric.hpp [code]
file | check_unit_vector.hpp [code]
file | check_vector.hpp [code]
file | constraint_tolerance.hpp [code]
file | validate_non_negative_index.hpp [code]

[ Stan Home Page ] © 2011–2016, Stan Development Team.